'use strict';

const DEFAULT_LISTENER_FROM_PARTNER_PORT = 25614;

const express = require('express');

const config = require('komodo-sdk/config');
const logger = require('komodo-sdk/logger');

const middlewareCommon = require('./middlewares/common');

const routerTrxStatus = require('./routers/trx-status');

const app = express();

app.use(middlewareCommon);

app.use('/trx-status', routerTrxStatus);

app.use((req, res) => {
    res.status(404).end('404: Method not found.');
});

app.listen(config.listener.partner.port || DEFAULT_LISTENER_FROM_PARTNER_PORT, () => {
    logger.info(`Listen from partner request on port ${config.listener.partner.port}`);
}).on('error', (e) => {
    logger.error(`Can not listen request from partner on port ${config.listener.partner.port || DEFAULT_LISTENER_FROM_PARTNER_PORT}. ${e.toString()}`);
    process.exit(1);
});
